@@ -1,6 +1,6 @@
 #!/bin/bash
 
-ALL_LANGUAGES="ru_RU fi_FI"
+ALL_LANGUAGES="ru_RU fi_FI es_ES es_MX"
 
 xgettext --from-code=UTF-8 --keyword=_ --keyword=Q_ -f po/POTFILES.in -s -C -o po/livewp.pot
 cd po
