@@ -23,4 +23,6 @@
 /*******************************************************************************/
 #include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
 #include <gtk/gtk.h>
-
+void lw_settings(Animation_WallpaperPrivate *priv, gpointer data);
+gint read_config(Animation_WallpaperPrivate *priv);
+void livewp_initialize_dbus(Animation_WallpaperPrivate *priv);
